<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package news_make
 */

get_header(); ?>
	<main class="main-container">
		<div class="container">
			<?php
				$enable_feature = news_make_get_option( 'news_make_enable_featured_post' );
				if ( is_active_sidebar( 'sidebar-2' ) && $enable_feature == 1 ) {
					dynamic_sidebar( 'sidebar-2' );
				}
			?>
			<div class="row section">
				<?php
					$sidebar_position = news_make_get_option( 'news_make_sidebar_position' );
					if( $sidebar_position == 'none' || !is_active_sidebar( 'sidebar-1' ) ) :
						$class = 'col-md-12';
					else :
						$class = 'col-md-8';
					endif;
					if( $sidebar_position == 'left' ) :
						get_sidebar();
					endif;
				?>
				<div class="<?php echo esc_attr( $class ); ?> sticky-section">
					<div class="row clearfix news-section">
						<div class="col-md-12">
						<?php
							/* Start the Loop */
							while ( have_posts() ) : the_post();

								/*
								 * Include the Post-Format-specific template for the content.
								 * If you want to override this in a child theme, then include a file
								 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
								 */
								get_template_part( 'template-parts/content', get_post_format() );

							endwhile;
						?>
						</div><!-- .col-md-12 -->
						<?php
							/**
							* Hook - news_make_pagination.
							*
							* @hooked news_make_pagination_action - 10
							*/
							do_action( 'news_make_pagination' );
						?>
					</div><!-- .row.clearfix.news-section -->
				</div><!-- .esc_attr( $class ) -->

				<?php
					if( $sidebar_position == 'right' ) :
						get_sidebar();
					endif;
				?>
			</div><!-- .row.section -->
		</div><!-- .container -->
	</main><!-- .main-container -->
<?php
get_footer();
